#include <iostream>
#include <string>
using namespace std;

#define NMAX 10
#define TPNMAX 2048
#define PRESSMAX 100

// Reprsentation du plateau tel qu'il est lu en entre.
// 1 correspond  la lumire allume "O".
// 0 correspond  la lumire teinte "#".
char board[NMAX][NMAX];

// Masque : comme l'algorithme tente toutes les possibilits pour la premire
// ligne, on utilise un masque. Si masque[i][j] vaut 1, cela signifie qu'il
// faut inverser board[i][j] pour connatre l'tat courant de la lumire (i,j).
// Autrement dit, l'tat actuel du panneau est (board XOR masque).
// Ainsi il est facile de remettre ce masque  zro pour tenter une nouvelle
// possibilit, plutt que de sauvegarder et remettre en place board.
char masque[NMAX][NMAX];

// Fonction qui change l'tat des lumires quand on appuie sur la case
// (i,j), en faisant attention aux bords...
void press(int i, int j)
{
	masque[i][j] = 1 - masque[i][j];
	// Changement de la case au-dessus
	if(i > 0)
	{
		masque[i - 1][j] = 1 - masque[i - 1][j];
	}
	// Changement de la case en-dessus
	if(i < NMAX - 1)
	{
		masque[i + 1][j] = 1 - masque[i + 1][j];
	}
	// Changement de la case  gauche
	if(j > 0)
	{
		masque[i][j - 1] = 1 - masque[i][j - 1];
	}
	// Changement de la case  droite
	if(j < NMAX - 1)
	{
		masque[i][j + 1] = 1 - masque[i][j + 1];
	}
}

// Calcul du nombre minimal d'appuis pour tout teindre.
int calc_presses()
{
	int min_presses = PRESSMAX + 10;
	int presses;

	// Pour chaque possibilit de masque de la premire ligne
	for(int m = 0; m < TPNMAX; m++)
	{
		presses = 0;

		// Remise  zro du masque
		for(int i = 0; i < NMAX; i++)
		{
			for(int j = 0; j < NMAX; j++)
			{
				masque[i][j] = 0;
			}
		}

		// On cre le masque pour la premire ligne, en fonction des
		// bits de m.
		for(int j = 0; j < NMAX; j++)
		{
			if(m & (1 << j))
			{
				press(0, j);
				presses++;
			}
		}

		// On itre ensuite sur les lignes suivantes, on appuie sur
		// une lumire si et seulement si la lumire au-dessus est
		// encore allume.
		for(int i = 1; i < NMAX; i++)
		{
			for(int j = 0; j < NMAX; j++)
			{
				// La lumire au-dessus est-elle allume ?
				if(board[i - 1][j] ^ masque[i - 1][j])
				{
					press(i, j);
					presses++;
				}
			}
		}
		
		// Si l'on possde un candidat (en nombre d'appuis sur les
		// lampes) pour amliorer le minimum...
		if(presses < min_presses)
		{
			// Toutes les lignes sont teintes, sauf ventuellement
			// la dernire. On vrifie qu'elle l'est effectivement.
			bool dern_allumee = false;
			for(int j = 0; j < NMAX; j++)
			{
				if(board[NMAX - 1][j] ^ masque[NMAX - 1][j])
				{
					dern_allumee = true;
				}
			}
			if(!dern_allumee)
			{
				min_presses = presses;
			}
		}
	}

	return min_presses;
}

int main()
{
	string label;

	// Boucle de lecture des donnes. La lecture de plusieurs messages
	// sur Usenet m'a convaincu qu'il est prfrable de faire une boucle
	// apparemment infinie plutt que de dupliquer le code ("cin >> label")
	// pour passer au cas suivant.
	while(true)
	{
		cin >> label;
		if(label == "end")
		{
			break;
		}

		for(int i = 0; i < NMAX; i++)
		{
			// Ignorer le caractre de fin de ligne
			cin.get();

			// On lit le tableau des lumires
			for(int j = 0; j < NMAX; j++)
			{
				char c;
				c = cin.get();
				if(c == 'O')
				{
					board[i][j] = 1;
				}
				if(c == '#')
				{
					board[i][j] = 0;
				}
			}
		}

		// Calcul du nombre minimal de lampes  presser
		int res = calc_presses();

		cout << label << " ";
		if(res > PRESSMAX)
		{
			cout << "-1";
		}
		else
		{
			cout << res;
		}
		cout << endl;
	}
}
