// Single-Player Games
// 664
// http://acm.uva.es/p/v6/664.html


#include <stdio.h>

const int nbLetter = 26;

// Array describing a tree equation
// The constant of an equation is stored at index n (NOT at index nbLetter!)
typedef double EQUA[nbLetter + 1];

static int n;
static EQUA equas[nbLetter];


// Read an equation from stdin.
// The open parenthesis '(' is supposed already read.
void readEqua(EQUA result)
{
	for (int i = 0; i <= n; i++)
		result[i] = 0.;
	
	for (int nbArg = 0;; nbArg++) {
		char c2[2];
		scanf("%1s", c2);
		const char c = c2[0];
		
		switch (c) {
			
			// Child (sub-equation): recurse
			case '(':
				{
					EQUA subresult;
					readEqua(subresult);
					for (int i = 0; i <= n; i++)
						result[i] += subresult[i];
				}
				break;
			
			// End of equation: normalize against children count
			case ')':
				for (int i = 0; i <= n; i++)
					result[i] /= nbArg;
				return;
			
			default:
				if ((c == '-') || ('0' <= c && c <= '9')) {
					// Number
					ungetc(c, stdin);
					int value;
					scanf("%d", &value);
					result[n] += value;
					
				}else if ('a' <= c && c <= 'z')
					// Letter
					result[c - 'a']++;
				break;
		}
	}
}


int main()
{
#ifdef _DEBUG
	freopen("SinglePlayer.in", "r", stdin);
#endif
	
	for (int game = 1;; game++) {
		scanf("%d", &n);
		if (!n)
			break;
		
		// Read the input
		// We don't store the trees: we only need the trees equation
		for (int i = 0; i < n; i++) {
			char buffer[2];
			scanf("%1s = (", buffer);
			readEqua(equas[i]);
			equas[i][i]--;
		}
		
		// Global remark: we do use "x == 0." to test nullity,
		// not the "fabs(x) < epsilon" method,
		// because positive nullity test is only required on exact null values.
		
		// Compute the LU decomposition of the equas[][] matrix
		// i = row (first dimension), j = column (second dimension)
		for (int j = 0; j < n; j++) {
			
			// Find not-null pivot
			int iPivot;
			for (iPivot = j; iPivot < n; iPivot++)
				if (equas[iPivot][j] != 0.)
					break;
			if (iPivot == n)
				continue;
			
			// Move the pivot line to the j-th line
			if (iPivot != j)
				for (int j2 = 0; j2 <= n; j2++)
					equas[j][j2] += equas[iPivot][j2];
			
			// "Pivotate" the matrix around the pivot line
			const double pivot = equas[j][j];
			for (int i = j + 1; i < n; i++) {
				const double factori = equas[i][j];
				if (factori != 0.)
					for (int j2 = 0; j2 <= n; j2++)
						equas[i][j2] = (equas[i][j2] * pivot) - (equas[j][j2] * factori);
			}
		}
		
		// Compute the variables
		bool   valuesOK[nbLetter];
		double values  [nbLetter];
		for (int i = n; --i >= 0;) {
			const double pivot = equas[i][i];
			bool ok = (pivot != 0.);
			double sum = equas[i][n];
			for (int j = i + 1; j < n; j++)
				if (equas[i][j] != 0.) {
					ok &= valuesOK[j];
					sum += equas[i][j] * values[j];
				}
			
			valuesOK[i] = ok;
			if (ok)
				values[i] = -sum / pivot;
		}
		
		// Print the results
		printf("Game %d\n", game);
		for (int i = 0; i < n; i++) {
			printf("Expected score for %c ", i + 'a');
			if (valuesOK[i])
				printf("= %.3f\n", values[i]);
			else
				puts("undefined");
		}
		putchar('\n');
	}
	
	return 0;
}
